/*****************************************************************************
 * VLC for iOS
 *****************************************************************************
 * Copyright (c) 2017 VideoLAN. All rights reserved.
 * $Id$
 *
 * Authors: Carola Nitz <nitz.carola # googlemail.com>
 *
 * Refer to the COPYING file of the official project for license.
 *****************************************************************************/

void _notAMethod(void)
{
    NSLocalizedString(@"STORE_DESCRIPTION", nil);
    NSLocalizedString(@"STORE_DESCRIPTION_TV", nil);
    NSLocalizedString(@"%d Failed Passcode Attempts", nil);
    NSLocalizedString(@"1 Failed Passcode Attempt", nil);
    NSLocalizedString(@"Change Passcode", nil);
    NSLocalizedString(@"Enter Passcode", nil);
    NSLocalizedString(@"Enter a passcode", nil);
    NSLocalizedString(@"Enter your new passcode", nil);
    NSLocalizedString(@"Enter your old passcode", nil);
    NSLocalizedString(@"Enter your passcode", nil);
    NSLocalizedString(@"Next", nil);
    NSLocalizedString(@"Passcodes did not match. Try again.", nil);
    NSLocalizedString(@"Re-enter your new passcode", nil);
    NSLocalizedString(@"Re-enter your passcode", nil);
    NSLocalizedString(@"Set Passcode", nil);
}
